@@ -1,4 +1,4 @@
-use Perlmazing;
+use Perlmazing qw(not_empty);
 
 sub main ($) {
 	not_empty($_[0]) ? 0 : 1;
