@@ -1,4 +1,4 @@
-use Perlmazing;
+use Perlmazing qw(_isa_ref);
 
 sub main ($) {
 	_isa_ref('IO', $_[0]);
